Event - Betty documentation

Hide navigation sidebar
Hide table of contents sidebar
Skip to content
Back to top
View this page
Toggle table of contents sidebar

# Event

An `betty.model.ancestry.Event` is something that happened at some time, such as a birth, death, or marriage.

## Fields

Events inherit from:

- Privacy

`date` (Datey)

  When the event took place.

`event_type` (EventType)

  The event’s type.

`files` (iterable of File)

  The files attached to this event.

`citations` (iterable of Citation)

  The citations for this event.

`description` (optional `str`)

  The event’s human-readable description.

`id` (`str`)

  The event’s own entity ID.

`place` (Place)

  Where the event took place.

`presences` (iterable of Presence)

  People’s presences at this event.